@@ -1,4 +1,4 @@
-'''
+r'''
 # aws-wafwebacl-appsync module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -135,6 +135,9 @@ Out of the box implementation of the Construct without any override will set the
 
 © Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -170,7 +173,7 @@ class WafwebaclToAppsync(
         *,
         existing_appsync_api: _aws_cdk_aws_appsync_ceddda9d.CfnGraphQLApi,
         existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        webacl_props: typing.Any = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -220,7 +223,7 @@ class WafwebaclToAppsyncProps:
         *,
         existing_appsync_api: _aws_cdk_aws_appsync_ceddda9d.CfnGraphQLApi,
         existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        webacl_props: typing.Any = None,
     ) -> None:
         '''
         :param existing_appsync_api: The existing Appsync API that will be protected with the WAF web ACL.
@@ -229,8 +232,6 @@ class WafwebaclToAppsyncProps:
 
         :summary: The properties for the WafwebaclToAppsync class.
         '''
-        if isinstance(webacl_props, dict):
-            webacl_props = _aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps(**webacl_props)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__6fd85c5128842da8bb7da69d48ffe2dc361a2ce2becdad52b1c5296c4fefff6f)
             check_type(argname="argument existing_appsync_api", value=existing_appsync_api, expected_type=type_hints["existing_appsync_api"])
@@ -260,15 +261,13 @@ class WafwebaclToAppsyncProps:
         return typing.cast(typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL], result)
 
     @builtins.property
-    def webacl_props(
-        self,
-    ) -> typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps]:
+    def webacl_props(self) -> typing.Any:
         '''Optional user-provided props to override the default props for the AWS WAF web ACL.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("webacl_props")
-        return typing.cast(typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps], result)
+        return typing.cast(typing.Any, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -295,7 +294,7 @@ def _typecheckingstub__ab36bcf291466e1edd94e156a9741b78f8c66d4f700d9207b00d2648e
     *,
     existing_appsync_api: _aws_cdk_aws_appsync_ceddda9d.CfnGraphQLApi,
     existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
-    webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    webacl_props: typing.Any = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -304,7 +303,7 @@ def _typecheckingstub__6fd85c5128842da8bb7da69d48ffe2dc361a2ce2becdad52b1c5296c4
     *,
     existing_appsync_api: _aws_cdk_aws_appsync_ceddda9d.CfnGraphQLApi,
     existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
-    webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    webacl_props: typing.Any = None,
 ) -> None:
     """Type checking stubs"""
     pass
